@@ -391,9 +391,9 @@ run_at (struct GNUNET_TIME_Absolute deadline)
                 GNUNET_TIME_absolute2s (deadline));
     return; /* too early */
   }
+  next_deadline = deadline;
   if (NULL != task)
     GNUNET_SCHEDULER_cancel (task);
-  next_deadline = deadline;
   task = GNUNET_SCHEDULER_add_at (deadline,
                                   &select_work,
                                   NULL);
@@ -513,7 +513,7 @@ deposit_get_cb (void *cls,
         qs = db_plugin->update_deposit_confirmation_status (
           db_plugin->cls,
           w->deposit_serial,
-          true, /* FIXME: should we set this to 'false' as we are awaiting KYC? */
+          true,
           GNUNET_TIME_absolute_to_timestamp (future_retry),
           w->retry_backoff,
           "Exchange reported 202 Accepted due to KYC/AML block");
@@ -567,8 +567,12 @@ deposit_get_cb (void *cls,
   GNUNET_assert (NULL != keys);
   if ( (w_count < CONCURRENCY_LIMIT / 2) ||
        (0 == w_count) )
+  {
+    if (NULL != task)
+      GNUNET_SCHEDULER_cancel (task);
     task = GNUNET_SCHEDULER_add_now (&select_work,
                                      NULL);
+  }
 }
 
 
@@ -774,6 +778,8 @@ keys_cb (
     return;
   }
   keys = TALER_EXCHANGE_keys_incref (in_keys);
+  if (NULL != task)
+    GNUNET_SCHEDULER_cancel (task);
   task = GNUNET_SCHEDULER_add_now (&select_work,
                                    NULL);
 }
