@@ -32,8 +32,8 @@
  * long-polling and do not want to wake up too often.
  */
 #define EXCHANGE_TIMEOUT GNUNET_TIME_relative_multiply ( \
-    GNUNET_TIME_UNIT_MINUTES, \
-    30)
+          GNUNET_TIME_UNIT_MINUTES, \
+          30)
 
 /**
  * How many inquiries do we process concurrently at most.
@@ -1154,7 +1154,8 @@ find_work (void *cls)
       return;
     }
     GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-                "No open inquiries found, waiting for notification to resume\n");
+                "No open inquiries found, waiting for notification to resume\n")
+    ;
   }
 }
 
@@ -1215,7 +1216,7 @@ run (void *cls,
   {
     GNUNET_break (0);
     GNUNET_SCHEDULER_shutdown ();
-    global_ret = EXIT_NO_RESTART;
+    global_ret = EXIT_FAILURE;
     return;
   }
   if (NULL ==
@@ -1233,7 +1234,7 @@ run (void *cls,
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
                 "Failed to connect to database\n");
     GNUNET_SCHEDULER_shutdown ();
-    global_ret = EXIT_NO_RESTART;
+    global_ret = EXIT_FAILURE;
     return;
   }
   {
