@@ -42,7 +42,7 @@
  * #MERCHANT_PROTOCOL_CURRENT and #MERCHANT_PROTOCOL_AGE in
  * merchant_api_config.c!
  */
-#define MERCHANT_PROTOCOL_VERSION "14:0:10"
+#define MERCHANT_PROTOCOL_VERSION "16:0:12"
 
 
 /**
@@ -82,14 +82,20 @@ MH_handler_config (struct TMH_RequestHandler *rh,
                    struct TMH_HandlerContext *hc)
 {
   static struct MHD_Response *response;
+  static struct GNUNET_TIME_Absolute a;
 
   (void) rh;
   (void) hc;
+  if ( (GNUNET_TIME_absolute_is_past (a)) &&
+       (NULL != response) )
+  {
+    MHD_destroy_response (response);
+    response = NULL;
+  }
   if (NULL == response)
   {
     json_t *specs = json_object ();
     json_t *exchanges = json_array ();
-    struct GNUNET_TIME_Absolute a;
     struct GNUNET_TIME_Timestamp km;
     char dat[128];
 
