@@ -19,6 +19,7 @@
  * @author Christian Blättler
  */
 #include "taler-merchant-httpd.h"
+#include <gnunet/gnunet_common.h>
 #include <gnunet/gnunet_time_lib.h>
 #include <jansson.h>
 
@@ -251,102 +252,92 @@ struct TALER_MerchantContractChoice
   unsigned int outputs_len;
 };
 
-struct TALER_MerchantContractLimits
+/**
+ * Public key and corresponding metadata for a token family.
+ */
+struct TALER_MerchantContractTokenFamilyKey
 {
   /**
-   * Currency these limits are for.
+   * Public key.
    */
-  char currency[TALER_CURRENCY_LEN];
+  struct TALER_TokenIssuePublicKeyP pub;
 
   /**
-   * The hash of the merchant instance's wire details.
+   * Tokens signed by this key will be valid after this time.
    */
-  struct TALER_MerchantWireHashP h_wire;
+  struct GNUNET_TIME_Timestamp valid_after;
 
   /**
-   * Wire transfer method identifier for the wire method associated with ``h_wire``.
-   * The wallet may only select exchanges via a matching auditor if the
-   * exchange also supports this wire method.
-   * The wire transfer fees must be added based on this wire transfer method.
+   * Tokens signed by this key will be valid before this time.
    */
-  char *wire_method;
-
-  /**
-   * Maximum total deposit fee accepted by the merchant for this contract.
-   */
-  struct TALER_Amount max_fee;
+  struct GNUNET_TIME_Timestamp valid_before;
 };
 
-struct TALER_MerchantContractTokenAuthority
+struct TALER_MerchantContractTokenFamily
 {
   /**
-  * Label of the token authority.
-  */
-  const char *label;
+   * Slug of the token family.
+   */
+  const char *slug;
 
   /**
-  * Human-readable description of the semantics of the tokens issued by
-  * this authority.
-  */
+   * Human-readable name of the token family.
+   */
+  char *name;
+
+  /**
+   * Human-readable description of the semantics of the tokens issued by
+   * this token family.
+   */
   char *description;
 
   /**
-  * Map from IETF BCP 47 language tags to localized description.
-  */
+   * Map from IETF BCP 47 language tags to localized description.
+   */
   json_t *description_i18n;
 
   /**
-  * Public key used to validate tokens signed by this authority.
-  */
-  struct TALER_TokenFamilyPublicKey *pub;
+   * Relevant public keys of this token family for the given contract.
+   */
+  struct TALER_MerchantContractTokenFamilyKey *keys;
 
   /**
-  * When will tokens signed by this key expire?
-  */
-  struct GNUNET_TIME_Timestamp token_expiration;
+   * Length of the @e keys array.
+   */
+  unsigned int keys_len;
 
   /**
-  * Must a wallet understand this token type to process contracts that
-  * consume or yield it?
-  */
+   * Must a wallet understand this token type to process contracts that
+   * consume or yield it?
+   */
   bool critical;
 
   /**
-  * Kind of the token.
-  */
+   * Kind of the token family.
+   */
   enum TALER_MerchantContractTokenKind kind;
 
   /**
-  * Kind-specific information about the token.
-  */
+   * Kind-specific information about the token.
+   */
   union
   {
     /**
-    * Subscription token.
-    */
+     * Subscription token.
+     */
     struct
     {
       /**
-      * When does the subscription period start?
-      */
-      struct GNUNET_TIME_Timestamp start_date;
-
-      /**
-      * When does the subscription period end?
-      */
-      struct GNUNET_TIME_Timestamp end_date;
-
-      /**
-      * Array of domain names where this subscription can be safely used
-      * (e.g. the issuer warrants that these sites will re-issue tokens of
-      * this type if the respective contract says so). May contain "*" for
-      * any domain or subdomain.
-      */
+       * Array of domain names where this subscription can be safely used
+       * (e.g. the issuer warrants that these sites will re-issue tokens of
+       * this type if the respective contract says so). May contain "*" for
+       * any domain or subdomain.
+       */
       const char **trusted_domains;
 
       /**
-      * Length of the @e trusted_domains array.
-      */
+       * Length of the @e trusted_domains array.
+       */
       unsigned int trusted_domains_len;
     } subscription;
 
@@ -356,19 +347,19 @@ struct TALER_MerchantContractTokenAuthority
     struct
     {
       /**
-      * Array of domain names where this discount token is intended to be
-      * used. May contain "*" for any domain or subdomain. Users should be
-      * warned about sites proposing to consume discount tokens of this
-      * type that are not in this list that the merchant is accepting a
-      * coupon from a competitor and thus may be attaching different
-      * semantics (like get 20% discount for my competitors 30% discount
-      * token).
-      */
+       * Array of domain names where this discount token is intended to be
+       * used. May contain "*" for any domain or subdomain. Users should be
+       * warned about sites proposing to consume discount tokens of this
+       * type that are not in this list that the merchant is accepting a
+       * coupon from a competitor and thus may be attaching different
+       * semantics (like get 20% discount for my competitors 30% discount
+       * token).
+       */
       const char **expected_domains;
 
       /**
-      * Length of the @e expected_domains array.
-      */
+       * Length of the @e expected_domains array.
+       */
       unsigned int expected_domains_len;
 
     } discount;
@@ -540,7 +531,7 @@ struct TALER_MerchantContract
   /**
    * Array of token authorities.
    */
-  struct TALER_MerchantContractTokenAuthority *token_authorities;
+  struct TALER_MerchantContractTokenFamily *token_authorities;
 
   /**
    * Length of the @e token_authorities array.
@@ -556,10 +547,16 @@ struct TALER_MerchantContract
 };
 
 enum TALER_MerchantContractInputType
-TMH_string_to_contract_input_type (const char *str);
+TMH_contract_input_type_from_string (const char *str);
 
 enum TALER_MerchantContractOutputType
-TMH_string_to_contract_output_type (const char *str);
+TMH_contract_output_type_from_string (const char *str);
+
+const char *
+TMH_string_from_contract_input_type (enum TALER_MerchantContractInputType t);
+
+const char *
+TMH_string_from_contract_output_type (enum TALER_MerchantContractOutputType t);
 
 /**
  * Serialize @a contract to a JSON object, ready to be stored in the database.
@@ -589,4 +586,53 @@ enum GNUNET_GenericReturnValue
 TMH_serialize_contract_v1 (const struct TALER_MerchantContract *contract,
                            const struct TMH_MerchantInstance *instance,
                            json_t *exchanges,
-                           json_t **out);
\ No newline at end of file
+                           json_t **out);
+
+/**
+ * Provide specification to parse given JSON array to an array
+ * of contract choices.
+ *
+ * @param name name of the choices field in the JSON
+ * @param[out] choices pointer to the first element of the array
+ * @param[out] choices_len pointer to the length of the array
+ * @return spec for parsing a choices array
+ */
+struct GNUNET_JSON_Specification
+TALER_JSON_spec_choices (const char *name,
+                         struct TALER_MerchantContractChoice **choices,
+                         unsigned int *choices_len);
+
+/**
+ * Provide specification to parse given JSON object to an array
+ * of token families.
+ *
+ * @param name name of the token families field in the JSON
+ * @param[out] families pointer to the first element of the array
+ * @param[out] families_len pointer to the length of the array
+ * @return spec for parsing a token families object
+ */
+struct GNUNET_JSON_Specification
+TALER_JSON_spec_token_families (const char *name,
+                                struct TALER_MerchantContractTokenFamily **families,
+                                unsigned int *families_len);
+
+
+/**
+ * Find matching token family in @a families based on @a slug. Then use
+ * @a valid_after to find the matching public key within it.
+ *
+ * @param slug slug of the token family
+ * @param valid_after start time of the validity period of the key
+ * @param families array of token families to search in
+ * @param families_len length of the @a families array
+ * @param[out] family found family, set to NULL to only check for existence
+ * @param[out] key found key, set to NULL to only check for existence
+ * @return #GNUNET_OK on success #GNUNET_NO if no key was found
+ */
+enum GNUNET_GenericReturnValue
+TMH_find_token_family_key (const char *slug,
+                           struct GNUNET_TIME_Timestamp valid_after,
+                           struct TALER_MerchantContractTokenFamily *families,
+                           unsigned int families_len,
+                           struct TALER_MerchantContractTokenFamily *family,
+                           struct TALER_MerchantContractTokenFamilyKey *key);
\ No newline at end of file
