@@ -372,6 +372,14 @@ TMH_EXCHANGES_get_master_pub (
 }
 
 
+const char *
+TMH_EXCHANGES_get_currency (
+  const struct TMH_Exchange *exchange)
+{
+  return exchange->currency;
+}
+
+
 /**
  * Free data structures within @a ea, but not @a ea
  * pointer itself.
