@@ -140,8 +140,20 @@ TMH_EXCHANGES_get_master_pub (
 
 
 /**
- * Lookup current wire fee by @a exchange_url and
- * @a wire_method.
+ * Return the currency of the given @a exchange.
+ * Will be returned from configuration for trusted
+ * exchanges.
+ *
+ * @param exchange exchange to get master public key for
+ * @return the currency of @a exchange
+ */
+const char *
+TMH_EXCHANGES_get_currency (
+  const struct TMH_Exchange *exchange);
+
+
+/**
+ * Lookup current wire fee by @a exchange_url and @a wire_method.
  *
  * @param exchange the exchange to check
  * @param wire_method wire method to lookup fee by
@@ -158,9 +170,8 @@ TMH_EXCHANGES_lookup_wire_fee (
 
 
 /**
- * Check if we would trust @a ex to deposit funds
- * into our account @a wm. Checks that both @a ex
- * is trusted and that @a ex allows wire transfers
+ * Check if we would trust @a ex to deposit funds into our account @a
+ * wm. Checks that both @a ex is trusted and that @a ex allows wire transfers
  * into the account given in @a wm.
  *
  * @param exchange the exchange to check
@@ -173,4 +184,16 @@ TMH_exchange_check_debit (
   const struct TMH_WireMethod *wm);
 
 
+/**
+ * Check if we support the given currency (by having an
+ * exchange configured with it).
+ *
+ * @param currency currency to check
+ * @return true if the currency is supported
+ */
+bool
+TMH_test_exchange_configured_for_currency (
+  const char *currency);
+
+
 #endif
