@@ -186,7 +186,7 @@ struct AbortContext
   /**
    * Number of coins this abort is for.  Length of the @e rd array.
    */
-  unsigned int coins_cnt;
+  size_t coins_cnt;
 
   /**
    * How often have we retried the 'main' transaction?
@@ -198,7 +198,7 @@ struct AbortContext
    * @e coins_cnt, decremented on each transaction that
    * successfully finished.
    */
-  unsigned int pending;
+  size_t pending;
 
   /**
    * Number of transactions still pending for the currently selected
@@ -206,7 +206,7 @@ struct AbortContext
    * exchange, decremented on each transaction that successfully
    * finished.  Once it hits zero, we pick the next exchange.
    */
-  unsigned int pending_at_ce;
+  size_t pending_at_ce;
 
   /**
    * HTTP status code to use for the reply, i.e 200 for "OK".
@@ -247,7 +247,7 @@ abort_refunds (struct AbortContext *ac)
 {
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
               "Aborting pending /deposit operations\n");
-  for (unsigned int i = 0; i<ac->coins_cnt; i++)
+  for (size_t i = 0; i<ac->coins_cnt; i++)
   {
     struct RefundDetails *rdi = &ac->rd[i];
 
@@ -356,7 +356,7 @@ generate_success_response (struct AbortContext *ac)
                              "could not create JSON array");
     return;
   }
-  for (unsigned int i = 0; i<ac->coins_cnt; i++)
+  for (size_t i = 0; i<ac->coins_cnt; i++)
   {
     struct RefundDetails *rdi = &ac->rd[i];
     json_t *detail;
@@ -424,7 +424,7 @@ abort_context_cleanup (void *cls)
     ac->timeout_task = NULL;
   }
   abort_refunds (ac);
-  for (unsigned int i = 0; i<ac->coins_cnt; i++)
+  for (size_t i = 0; i<ac->coins_cnt; i++)
   {
     struct RefundDetails *rdi = &ac->rd[i];
 
@@ -522,7 +522,7 @@ process_abort_with_exchange (void *cls,
   /* Initiate refund operation for all coins of
      the current exchange (!) */
   GNUNET_assert (0 == ac->pending_at_ce);
-  for (unsigned int i = 0; i<ac->coins_cnt; i++)
+  for (size_t i = 0; i<ac->coins_cnt; i++)
   {
     struct RefundDetails *rdi = &ac->rd[i];
 
@@ -579,7 +579,7 @@ begin_transaction (struct AbortContext *ac);
 static void
 find_next_exchange (struct AbortContext *ac)
 {
-  for (unsigned int i = 0; i<ac->coins_cnt; i++)
+  for (size_t i = 0; i<ac->coins_cnt; i++)
   {
     struct RefundDetails *rdi = &ac->rd[i];
 
@@ -635,7 +635,7 @@ refund_coins (void *cls,
   (void) deposit_fee;
   (void) refund_fee;
   now = GNUNET_TIME_timestamp_get ();
-  for (unsigned int i = 0; i<ac->coins_cnt; i++)
+  for (size_t i = 0; i<ac->coins_cnt; i++)
   {
     struct RefundDetails *rdi = &ac->rd[i];
     enum GNUNET_DB_QueryStatus qs;
