@@ -62,7 +62,6 @@ claim_order (const char *instance_id,
   struct TALER_ClaimTokenP order_ct;
   enum GNUNET_DB_QueryStatus qs;
   uint64_t order_serial;
-  bool paid = false;
 
   if (GNUNET_OK !=
       TMH_db->start (TMH_db->cls,
@@ -76,7 +75,6 @@ claim_order (const char *instance_id,
                                       order_id,
                                       contract_terms,
                                       &order_serial,
-                                      &paid,
                                       NULL);
   if (0 > qs)
   {
