@@ -565,7 +565,8 @@ TMH_post_orders_ID_refund (const struct TMH_RequestHandler *rh,
       enum GNUNET_GenericReturnValue res;
 
       struct GNUNET_JSON_Specification spec[] = {
-        GNUNET_JSON_spec_fixed_auto ("h_contract", &prd->h_contract_terms),
+        GNUNET_JSON_spec_fixed_auto ("h_contract",
+                                     &prd->h_contract_terms),
         GNUNET_JSON_spec_end ()
       };
       res = TALER_MHD_parse_json_data (connection,
@@ -666,8 +667,9 @@ TMH_post_orders_ID_refund (const struct TMH_RequestHandler *rh,
   }
 
   {
-    GNUNET_assert (GNUNET_OK == TALER_amount_set_zero (TMH_currency,
-                                                       &prd->refund_amount));
+    GNUNET_assert (GNUNET_OK ==
+                   TALER_amount_set_zero (TMH_currency,
+                                          &prd->refund_amount));
     qs = TMH_db->lookup_refunds_detailed (TMH_db->cls,
                                           hc->instance->settings.id,
                                           &prd->h_contract_terms,
