@@ -684,7 +684,7 @@ kyc_with_exchange (void *cls,
     keys,
     ekr->exchange_kyc_serial,
     &h_payto,
-    ekr->kc->mi->settings.ut,
+    1, /* FIXME: this will go away! */
     GNUNET_TIME_absolute_get_remaining (kc->timeout),
     &exchange_check_cb,
     ekr);
