@@ -22,6 +22,9 @@
 #include "platform.h"
 #include "taler-merchant-httpd_private-get-orders-ID.h"
 #include "taler-merchant-httpd_get-orders-ID.h"
+#include <gnunet/gnunet_json_lib.h>
+#include <jansson.h>
+#include <stdint.h>
 #include <taler/taler_json_lib.h>
 #include <taler/taler_dbevents.h>
 #include "taler-merchant-httpd_mhd.h"
@@ -315,6 +318,12 @@ struct GetOrderRequestContext
    */
   uint64_t order_serial;
 
+  /**
+   * Index of selected choice from ``choices`` array in the contract_terms.
+   * Is -1 for orders without choices.
+   */
+  int16_t choice_index;
+
   /**
    * Total refunds granted for this payment. Only initialized
    * if @e refunded is set to true.
@@ -610,6 +619,7 @@ phase_fetch_contract (struct GetOrderRequestContext *gorc)
     gorc->order_only = false;
   }
   TMH_db->preflight (TMH_db->cls);
+  /* TODO: Check if choice_index is actually set to NULL if not in db. */
   qs = TMH_db->lookup_contract_terms3 (TMH_db->cls,
                                        hc->instance->settings.id,
                                        hc->infix,
@@ -619,7 +629,8 @@ phase_fetch_contract (struct GetOrderRequestContext *gorc)
                                        &gorc->paid,
                                        &gorc->wired,
                                        &gorc->paid_session_matches,
-                                       &gorc->claim_token);
+                                       &gorc->claim_token,
+                                       &gorc->choice_index);
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "lookup_contract_terms (%s) returned %d\n",
               hc->infix,
@@ -1376,6 +1387,7 @@ phase_reply_result (struct GetOrderRequestContext *gorc)
   struct TMH_HandlerContext *hc = gorc->hc;
   MHD_RESULT ret;
   char *order_status_url;
+  json_t *choice_index = json_null();
 
   {
     struct TALER_PrivateContractHashP *h_contract = NULL;
@@ -1403,6 +1415,12 @@ phase_reply_result (struct GetOrderRequestContext *gorc)
                   TALER_amount_is_zero (&gorc->contract_amount));
     gorc->last_payment = gorc->timestamp;
   }
+  if (-1 != gorc->choice_index) {
+    GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
+                "Choice index is %d\n",
+                gorc->choice_index);
+    choice_index = json_integer ((json_int_t) gorc->choice_index);
+  }
   ret = TALER_MHD_REPLY_JSON_PACK (
     gorc->sc.con,
     MHD_HTTP_OK,
@@ -1440,7 +1458,11 @@ phase_reply_result (struct GetOrderRequestContext *gorc)
     GNUNET_JSON_pack_array_steal ("refund_details",
                                   gorc->refund_details),
     GNUNET_JSON_pack_string ("order_status_url",
-                             order_status_url));
+                             order_status_url),
+    {
+      .field_name = "choice_index",
+      .object = choice_index,
+    });
   GNUNET_free (order_status_url);
   gorc->wire_details = NULL;
   gorc->refund_details = NULL;
