@@ -32,19 +32,25 @@
  * @return MHD result code
  */
 MHD_RESULT
-TMH_private_get_products_ID (const struct TMH_RequestHandler *rh,
-                             struct MHD_Connection *connection,
-                             struct TMH_HandlerContext *hc)
+TMH_private_get_products_ID (
+  const struct TMH_RequestHandler *rh,
+  struct MHD_Connection *connection,
+  struct TMH_HandlerContext *hc)
 {
   struct TMH_MerchantInstance *mi = hc->instance;
   struct TALER_MERCHANTDB_ProductDetails pd = { 0 };
   enum GNUNET_DB_QueryStatus qs;
+  size_t num_categories = 0;
+  uint64_t *categories = NULL;
+  json_t *jcategories;
 
   GNUNET_assert (NULL != mi);
   qs = TMH_db->lookup_product (TMH_db->cls,
                                mi->settings.id,
                                hc->infix,
-                               &pd);
+                               &pd,
+                               &num_categories,
+                               &categories);
   if (0 > qs)
   {
     GNUNET_break (0);
@@ -60,6 +66,16 @@ TMH_private_get_products_ID (const struct TMH_RequestHandler *rh,
                                        TALER_EC_MERCHANT_GENERIC_PRODUCT_UNKNOWN,
                                        hc->infix);
   }
+  jcategories = json_array ();
+  GNUNET_assert (NULL != jcategories);
+  for (size_t i = 0; i<num_categories; i++)
+  {
+    GNUNET_assert (0 ==
+                   json_array_append_new (jcategories,
+                                          json_integer (categories[i])));
+  }
+  GNUNET_free (categories);
+
   {
     MHD_RESULT ret;
 
@@ -72,12 +88,16 @@ TMH_private_get_products_ID (const struct TMH_RequestHandler *rh,
                                      pd.description_i18n),
       GNUNET_JSON_pack_string ("unit",
                                pd.unit),
+      GNUNET_JSON_pack_array_steal ("categories",
+                                    jcategories),
       TALER_JSON_pack_amount ("price",
                               &pd.price),
-      GNUNET_JSON_pack_string ("image",
-                               pd.image),
-      GNUNET_JSON_pack_array_steal ("taxes",
-                                    pd.taxes),
+      GNUNET_JSON_pack_allow_null (
+        GNUNET_JSON_pack_string ("image",
+                                 pd.image)),
+      GNUNET_JSON_pack_allow_null (
+        GNUNET_JSON_pack_array_steal ("taxes",
+                                      pd.taxes)),
       GNUNET_JSON_pack_int64 ("total_stock",
                               (INT64_MAX == pd.total_stock)
                               ? -1LL
@@ -86,8 +106,9 @@ TMH_private_get_products_ID (const struct TMH_RequestHandler *rh,
                                pd.total_sold),
       GNUNET_JSON_pack_uint64 ("total_lost",
                                pd.total_lost),
-      GNUNET_JSON_pack_object_steal ("address",
-                                     pd.address),
+      GNUNET_JSON_pack_allow_null (
+        GNUNET_JSON_pack_object_steal ("address",
+                                       pd.address)),
       GNUNET_JSON_pack_allow_null (
         GNUNET_JSON_pack_timestamp ("next_restock",
                                     (pd.next_restock))),
