@@ -20,6 +20,7 @@
  */
 #include "platform.h"
 #include "taler-merchant-httpd_private-get-token-families-SLUG.h"
+#include <gnunet/gnunet_json_lib.h>
 #include <taler/taler_json_lib.h>
 
 
@@ -84,6 +85,7 @@ TMH_private_get_tokenfamilies_SLUG (const struct TMH_RequestHandler *rh,
     result = TALER_MHD_REPLY_JSON_PACK (
       connection,
       MHD_HTTP_OK,
+      GNUNET_JSON_pack_string ("slug", details.slug),
       GNUNET_JSON_pack_string ("name", details.name),
       GNUNET_JSON_pack_string ("description", details.description),
       GNUNET_JSON_pack_object_steal ("description_i18n",
@@ -91,7 +93,9 @@ TMH_private_get_tokenfamilies_SLUG (const struct TMH_RequestHandler *rh,
       GNUNET_JSON_pack_timestamp ("valid_after", details.valid_after),
       GNUNET_JSON_pack_timestamp ("valid_before", details.valid_before),
       GNUNET_JSON_pack_time_rel ("duration", details.duration),
-      GNUNET_JSON_pack_string ("kind", kind)
+      GNUNET_JSON_pack_string ("kind", kind),
+      GNUNET_JSON_pack_int64 ("issued", details.issued),
+      GNUNET_JSON_pack_int64 ("used", details.used)
       );
 
     GNUNET_free (details.name);
