@@ -103,20 +103,6 @@ TMH_private_post_instances (const struct TMH_RequestHandler *rh,
              ? MHD_YES
              : MHD_NO;
   }
-  if (NULL == uts)
-    uts = "business";
-  if (GNUNET_OK !=
-      TALER_KYCLOGIC_kyc_user_type_from_string (uts,
-                                                &is.ut))
-  {
-    GNUNET_break_op (0);
-    GNUNET_JSON_parse_free (spec);
-    return TALER_MHD_reply_with_error (connection,
-                                       MHD_HTTP_BAD_REQUEST,
-                                       TALER_EC_GENERIC_PARAMETER_MALFORMED,
-                                       "user_type");
-  }
-
   {
     enum GNUNET_GenericReturnValue ret;
 
