@@ -118,13 +118,7 @@ static enum GNUNET_GenericReturnValue
 build_webui (void *cls,
              const char *dn)
 {
-  int fd;
-  struct stat sb;
-  struct MHD_Response *zspa;
-  struct MHD_Response *spa;
-  const char *ext;
-  const char *mime;
-  struct
+  static struct
   {
     const char *ext;
     const char *mime;
@@ -162,6 +156,12 @@ build_webui (void *cls,
       .mime = NULL
     },
   };
+  int fd;
+  struct stat sb;
+  struct MHD_Response *zspa = NULL;
+  struct MHD_Response *spa;
+  const char *ext;
+  const char *mime;
 
   (void) cls;
   /* finally open template */
@@ -187,7 +187,11 @@ build_webui (void *cls,
 
   mime = NULL;
   ext = strrchr (dn, '.');
-  GNUNET_assert (NULL != ext);
+  if (NULL == ext)
+  {
+    GNUNET_break (0 == close (fd));
+    return GNUNET_OK;
+  }
   ext++;
   for (unsigned int i = 0; NULL != mime_map[i].ext; i++)
     if (0 == strcasecmp (ext,
