@@ -70,10 +70,14 @@ TMH_PG_insert_deposit_confirmation (
 
   /* no preflight check here, run in transaction by caller! */
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-              "Storing deposit confirmation for instance `%s' h_contract_terms `%s', total_without_fees: %s\n",
+              "Storing deposit confirmation for instance `%s' h_contract_terms `%s', total_without_fees: %s and wire transfer deadline in %s\n",
               instance_id,
               GNUNET_h2s (&h_contract_terms->hash),
-              TALER_amount2s (total_without_fees));
+              TALER_amount2s (total_without_fees),
+              GNUNET_TIME_relative2s (
+                GNUNET_TIME_absolute_get_remaining (
+                  wire_transfer_deadline.abs_time),
+                true));
   check_connection (pg);
   PREPARE (pg,
            "insert_deposit_confirmation",
