@@ -73,8 +73,8 @@ TMH_PG_lookup_token_family (void *cls,
                                     &kind),
       GNUNET_PQ_result_spec_uint64 ("issued",
                                     &details->issued),
-      GNUNET_PQ_result_spec_uint64 ("redeemed",
-                                    &details->redeemed),
+      GNUNET_PQ_result_spec_uint64 ("used",
+                                    &details->used),
       GNUNET_PQ_result_spec_end
     };
 
@@ -91,7 +91,7 @@ TMH_PG_lookup_token_family (void *cls,
              ",duration"
              ",kind"
              ",issued"
-             ",redeemed"
+             ",used"
              " FROM merchant_token_families"
              " JOIN merchant_instances"
              "   USING (merchant_serial)"
