@@ -143,11 +143,10 @@ TMH_PG_select_accounts (void *cls,
            ",credit_facade_credentials"
            ",active"
            " FROM merchant_accounts"
-           " WHERE active"
-           "   AND merchant_serial="
-           "     (SELECT merchant_serial "
-           "       FROM merchant_instances"
-           "        WHERE merchant_id=$1);");
+           " WHERE merchant_serial="
+           "   (SELECT merchant_serial "
+           "      FROM merchant_instances"
+           "     WHERE merchant_id=$1);");
   qs = GNUNET_PQ_eval_prepared_multi_select (pg->conn,
                                              "select_accounts",
                                              params,
