@@ -614,6 +614,8 @@ TALER_TESTING_cmd_merchant_post_orders3 (
  *        the proposal request.
  * @param http_status expected HTTP status.
  * @param token_family_reference label of the POST /tokenfamilies cmd.
+ * @param num_inputs number of input tokens.
+ * @param num_outputs number of output tokens.
  * @param order_id the name of the order to add.
  * @param refund_deadline the deadline for refunds on this order.
  * @param pay_deadline the deadline for payment on this order.
@@ -628,6 +630,8 @@ TALER_TESTING_cmd_merchant_post_orders_choices (
   const char *merchant_url,
   unsigned int http_status,
   const char *token_family_reference,
+  unsigned int num_inputs,
+  unsigned int num_outputs,
   const char *order_id,
   struct GNUNET_TIME_Timestamp refund_deadline,
   struct GNUNET_TIME_Timestamp pay_deadline,
@@ -983,6 +987,39 @@ TALER_TESTING_cmd_merchant_pay_order (
   const char *session_id);
 
 
+/**
+ * Make a "pay" test command for an order with choices.
+ *
+ * @param label command label.
+ * @param merchant_url merchant base url
+ * @param http_status expected HTTP response code.
+ * @param proposal_reference the proposal whose payment status
+ *        is going to be checked.
+ * @param coin_reference reference to any command which is able
+ *        to provide coins to use for paying.
+ * @param amount_with_fee amount to pay, including the deposit
+ *        fee
+ * @param amount_without_fee amount to pay, no fees included.
+ * @param session_id the session id to use for the payment (can be NULL).
+ * @param choice_index index of the selected choice for the payment.
+ * @param input_reference reference to a previous pay command that issued some
+          outputs to be used as inputs to this pay request.
+ * @return the command
+ */
+struct TALER_TESTING_Command
+TALER_TESTING_cmd_merchant_pay_order_choices (
+  const char *label,
+  const char *merchant_url,
+  unsigned int http_status,
+  const char *proposal_reference,
+  const char *coin_reference,
+  const char *amount_with_fee,
+  const char *amount_without_fee,
+  const char *session_id,
+  int choice_index,
+  const char *input_reference);
+
+
 /**
  * Make an "order paid" test command.
  *
@@ -1535,6 +1572,7 @@ TALER_TESTING_cmd_merchant_post_tokenfamilies (
   struct GNUNET_TIME_Timestamp valid_after,
   struct GNUNET_TIME_Timestamp valid_before,
   struct GNUNET_TIME_Relative duration,
+  struct GNUNET_TIME_Relative rounding,
   const char *kind);
 
 /* ****** Webhooks ******* */
@@ -1823,7 +1861,10 @@ TALER_TESTING_cmd_checkserver2 (const char *label,
   op (http_header, const char)   \
   op (http_body, const void)   \
   op (http_body_size, const size_t)   \
-  op (planchet_secrets, const struct TALER_PlanchetMasterSecretP)
+  op (planchet_secrets, const struct TALER_PlanchetMasterSecretP)   \
+  op (token_priv, const struct TALER_TokenUsePrivateKeyP)   \
+  op (token_issue_sig, const struct TALER_TokenIssueSignatureP)   \
+  op (token_issue_pub, const struct TALER_TokenIssuePublicKeyP)
 
 
 TALER_MERCHANT_TESTING_SIMPLE_TRAITS (TALER_TESTING_MAKE_DECL_SIMPLE_TRAIT)
