@@ -92,19 +92,16 @@ handle_get_template_finished (void *cls,
   {
   case MHD_HTTP_OK:
     {
-      uint32_t alg32;
-      json_t *contract;
+      const json_t *contract;
       struct GNUNET_JSON_Specification spec[] = {
         GNUNET_JSON_spec_string ("template_description",
-                                 &tgr.details.success.template_description),
-        GNUNET_JSON_spec_uint32 ("pos_algorithm",
-                                 &alg32),
+                                 &tgr.details.ok.template_description),
         GNUNET_JSON_spec_mark_optional (
-          GNUNET_JSON_spec_string ("pos_key",
-                                   &tgr.details.success.pos_key),
+          GNUNET_JSON_spec_string ("otp_id",
+                                   &tgr.details.ok.otp_id),
           NULL),
-        GNUNET_JSON_spec_json ("template_contract",
-                               &contract),
+        GNUNET_JSON_spec_object_const ("template_contract",
+                                       &contract),
         GNUNET_JSON_spec_end ()
       };
 
@@ -113,18 +110,14 @@ handle_get_template_finished (void *cls,
                              spec,
                              NULL, NULL))
       {
-        tgr.details.success.mca =
-          (enum TALER_MerchantConfirmationAlgorithm) alg32;
-        tgr.details.success.template_contract = contract;
+        tgr.details.ok.template_contract = contract;
         tgh->cb (tgh->cb_cls,
                  &tgr);
-        GNUNET_JSON_parse_free (spec);
         TALER_MERCHANT_template_get_cancel (tgh);
         return;
       }
       tgr.hr.http_status = 0;
       tgr.hr.ec = TALER_EC_GENERIC_INVALID_RESPONSE;
-      GNUNET_JSON_parse_free (spec);
       break;
     }
   case MHD_HTTP_UNAUTHORIZED:
