@@ -123,11 +123,10 @@ handle_post_transfers_finished (void *cls,
     ptr.hr.ec = TALER_JSON_get_error_code (ptr.hr.reply);
     ptr.hr.hint = TALER_JSON_get_error_hint (ptr.hr.reply);
     {
-      uint32_t eec;
       uint32_t ehc;
       struct GNUNET_JSON_Specification ispec[] = {
-        GNUNET_JSON_spec_uint32 ("exchange_code",
-                                 &eec),
+        TALER_JSON_spec_ec ("exchange_code",
+                            &ptr.details.bad_gateway.exchange_ec),
         GNUNET_JSON_spec_uint32 ("exchange_http_status",
                                  &ehc),
         GNUNET_JSON_spec_end ()
@@ -147,11 +146,9 @@ handle_post_transfers_finished (void *cls,
       {
         ptr.details.bad_gateway.exchange_http_status
           = (unsigned int) ehc;
-        ptr.details.bad_gateway.exchange_ec
-          = (enum TALER_ErrorCode) eec;
         GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
                     "Exchange returned %u/%u\n",
-                    (unsigned int) eec,
+                    (unsigned int) ptr.details.bad_gateway.exchange_ec,
                     (unsigned int) ehc);
       }
     }
