@@ -1682,6 +1682,35 @@ run (void *cls,
                                        "EUR:5",
                                        0,
                                        MHD_HTTP_OK),
+    TALER_TESTING_cmd_merchant_post_tokenfamilies ("create-upcoming-tokenfamily",
+                                                   merchant_url,
+                                                   MHD_HTTP_NO_CONTENT,
+                                                   "subscription-upcoming",
+                                                   "Upcoming Subscription",
+                                                   "An upcoming subscription that is not valid yet.",
+                                                   NULL,
+                                                   /* In one day */
+                                                   GNUNET_TIME_absolute_to_timestamp (
+                                                    GNUNET_TIME_absolute_add (
+                                                      GNUNET_TIME_timestamp_get ().abs_time, GNUNET_TIME_UNIT_DAYS)),
+                                                   /* In a year */
+                                                   GNUNET_TIME_absolute_to_timestamp (
+                                                    GNUNET_TIME_absolute_add (
+                                                      GNUNET_TIME_timestamp_get ().abs_time, GNUNET_TIME_UNIT_YEARS)),
+                                                   GNUNET_TIME_UNIT_MONTHS,
+                                                   GNUNET_TIME_UNIT_MONTHS,
+                                                   "subscription"),
+    TALER_TESTING_cmd_merchant_post_orders_choices ("create-order-with-upcoming-output",
+                                                    cred.cfg,
+                                                    merchant_url,
+                                                    MHD_HTTP_CONFLICT,
+                                                    "create-upcoming-tokenfamily",
+                                                    0,
+                                                    1,
+                                                    "5-upcoming-output",
+                                                    GNUNET_TIME_UNIT_ZERO_TS,
+                                                    GNUNET_TIME_UNIT_FOREVER_TS,
+                                                    "EUR:5.0"),
     TALER_TESTING_cmd_merchant_post_tokenfamilies ("create-tokenfamily",
                                                    merchant_url,
                                                    MHD_HTTP_NO_CONTENT,
@@ -1689,20 +1718,84 @@ run (void *cls,
                                                    "Subscription",
                                                    "A subscription.",
                                                    NULL,
-                                                   GNUNET_TIME_timestamp_get (),
+                                                   GNUNET_TIME_UNIT_ZERO_TS,
                                                    GNUNET_TIME_relative_to_timestamp (GNUNET_TIME_UNIT_YEARS),
                                                    GNUNET_TIME_UNIT_MONTHS,
+                                                   GNUNET_TIME_UNIT_MONTHS,
                                                    "subscription"),
-    TALER_TESTING_cmd_merchant_post_orders_choices ("create-order-with-choices",
+    TALER_TESTING_cmd_merchant_post_orders_choices ("create-order-with-output",
                                                     cred.cfg,
                                                     merchant_url,
                                                     MHD_HTTP_OK,
                                                     "create-tokenfamily",
-                                                    "5-choices",
+                                                    0,
+                                                    1,
+                                                    "5-output",
                                                     GNUNET_TIME_UNIT_ZERO_TS,
                                                     GNUNET_TIME_UNIT_FOREVER_TS,
                                                     "EUR:5.0"),
-
+    TALER_TESTING_cmd_merchant_pay_order_choices ("pay-order-with-output",
+                                                  merchant_url,
+                                                  MHD_HTTP_OK,
+                                                  "create-order-with-output",
+                                                  "withdraw-coin-1",
+                                                  "EUR:5",
+                                                  "EUR:4.99",
+                                                  NULL,
+                                                  0,
+                                                  NULL),
+    TALER_TESTING_cmd_merchant_post_orders_choices ("create-order-with-input-and-output",
+                                                    cred.cfg,
+                                                    merchant_url,
+                                                    MHD_HTTP_OK,
+                                                    "create-tokenfamily",
+                                                    1,
+                                                    1,
+                                                    "5-input-output",
+                                                    GNUNET_TIME_UNIT_ZERO_TS,
+                                                    GNUNET_TIME_UNIT_FOREVER_TS,
+                                                    "EUR:0.0"),
+    TALER_TESTING_cmd_merchant_pay_order_choices ("pay-order-with-input-and-output",
+                                                  merchant_url,
+                                                  MHD_HTTP_OK,
+                                                  "create-order-with-input-and-output",
+                                                  "",
+                                                  "EUR:0",
+                                                  "EUR:0",
+                                                  NULL,
+                                                  0,
+                                                  "pay-order-with-output"),
+    // TALER_TESTING_cmd_merchant_pay_order_choices ("idempotent-pay-order-with-input-and-output",
+    //                                               merchant_url,
+    //                                               MHD_HTTP_OK,
+    //                                               "create-order-with-input-and-output",
+    //                                               "",
+    //                                               "EUR:0",
+    //                                               "EUR:0",
+    //                                               NULL,
+    //                                               0,
+    //                                               "pay-order-with-output"),
+    TALER_TESTING_cmd_merchant_post_orders_choices ("create-another-order-with-input-and-output",
+                                                    cred.cfg,
+                                                    merchant_url,
+                                                    MHD_HTTP_OK,
+                                                    "create-tokenfamily",
+                                                    1,
+                                                    1,
+                                                    "5-input-output-2",
+                                                    GNUNET_TIME_UNIT_ZERO_TS,
+                                                    GNUNET_TIME_UNIT_FOREVER_TS,
+                                                    "EUR:0.0"),
+    TALER_TESTING_cmd_merchant_pay_order_choices ("double-spend-token",
+                                                  merchant_url,
+                                                  MHD_HTTP_CONFLICT,
+                                                  "create-another-order-with-input-and-output",
+                                                  "",
+                                                  "EUR:0",
+                                                  "EUR:0",
+                                                  NULL,
+                                                  0,
+                                                  "pay-order-with-output"),
     TALER_TESTING_cmd_end ()
   };
 
