@@ -62,7 +62,7 @@ static char *config_file;
 #define USER_ACCOUNT_NAME "62"
 
 
-#define PAYTO_I1 "payto://x-taler-bank/localhost/3"
+#define PAYTO_I1 "payto://x-taler-bank/localhost/3?receiver-name=user3"
 
 
 /**
@@ -226,7 +226,7 @@ run (void *cls,
      * so we'll then have the right to abort.  */
     TALER_TESTING_cmd_merchant_pay_order ("deposit-simple-for-abort",
                                           twister_merchant_url,
-                                          MHD_HTTP_NOT_ACCEPTABLE,
+                                          MHD_HTTP_BAD_REQUEST,
                                           "create-proposal-abort-1",
                                           "withdraw-coin-abort-1",
                                           "EUR:1.01",
@@ -339,11 +339,11 @@ run (void *cls,
                                                "default",
                                                MHD_HTTP_NO_CONTENT),
     TALER_TESTING_cmd_merchant_post_account (
-        "instance-create-default-account",
-        twister_merchant_url,
-        PAYTO_I1,
-        NULL, NULL,
-        MHD_HTTP_OK),
+      "instance-create-default-account",
+      twister_merchant_url,
+      PAYTO_I1,
+      NULL, NULL,
+      MHD_HTTP_OK),
     TALER_TESTING_cmd_batch ("pay",
                              pay),
     /* Malform the response from the exchange. */
@@ -401,7 +401,7 @@ run (void *cls,
                                             "EUR:6.0"),
     TALER_TESTING_cmd_merchant_pay_order ("deposit-2",
                                           merchant_url,
-                                          MHD_HTTP_NOT_ACCEPTABLE,
+                                          MHD_HTTP_BAD_REQUEST,
                                           "create-proposal-2",
                                           "withdraw-coin-1",
                                           "EUR:5",
@@ -452,9 +452,14 @@ main (int argc,
                      cipher);
     GNUNET_free (cipher);
   }
-  payer_payto = "payto://x-taler-bank/localhost/" USER_ACCOUNT_NAME;
-  exchange_payto = "payto://x-taler-bank/localhost/" EXCHANGE_ACCOUNT_NAME;
-  merchant_payto = "payto://x-taler-bank/localhost/" MERCHANT_ACCOUNT_NAME;
+  payer_payto =
+    "payto://x-taler-bank/localhost/" USER_ACCOUNT_NAME "?receiver-name=user";
+  exchange_payto =
+    "payto://x-taler-bank/localhost/" EXCHANGE_ACCOUNT_NAME
+    "?receiver-name=exchange";
+  merchant_payto =
+    "payto://x-taler-bank/localhost/" MERCHANT_ACCOUNT_NAME
+    "?receiver-name=merchant";
   merchant_url = "http://localhost:8080/";
   if (NULL == (twister_exchange_url = TALER_TWISTER_prepare_twister (
                  PROXY_EXCHANGE_config_file)))
