@@ -41,7 +41,7 @@ fi
 STATUS=$(curl -H "Content-Type: application/json" -X POST \
     -H 'Authorization: Bearer secret-token:super_secret' \
     http://localhost:9966/private/accounts \
-    -d '{"payto_uri":"payto://x-taler-bank/localhost:8082/43"}' \
+    -d '{"payto_uri":"payto://x-taler-bank/localhost:8082/43?receiver-name=user43"}' \
     -w "%{http_code}" -s -o /dev/null)
 
 
@@ -53,7 +53,7 @@ fi
 STATUS=$(curl -H "Content-Type: application/json" -X POST \
     -H 'Authorization: Bearer secret-token:super_secret' \
     http://localhost:9966/private/accounts \
-    -d '{"payto_uri":"payto://x-taler-bank/localhost:8082/44"}' \
+    -d '{"payto_uri":"payto://x-taler-bank/localhost:8082/44?receiver-name=user44"}' \
     -w "%{http_code}" -s -o /dev/null)
 
 
