@@ -28,6 +28,10 @@ then
     BANK_FLAGS="-f -d $WIRE_METHOD -u $ACCOUNT"
     BANK_URL="http://localhost:8082/"
 else
+    echo -n "Testing for libeufin-bank"
+    libeufin-bank --help >/dev/null </dev/null || exit_skip " MISSING"
+    echo " FOUND"
+
     ACCOUNT="exchange-account-1"
     WIRE_METHOD="iban"
     BANK_FLAGS="-ns -d $WIRE_METHOD -u $ACCOUNT"
@@ -36,6 +40,12 @@ fi
 
 . setup.sh
 
+
+echo -n "Testing for taler-harness"
+taler-harness --help >/dev/null </dev/null || exit_skip " MISSING"
+echo " FOUND"
+
+
 # Launch system.
 setup -c "test_template.conf" \
       -em \
@@ -65,7 +75,7 @@ fi
 
 STATUS=$(curl -H "Content-Type: application/json" -X POST \
     -H 'Authorization: Bearer secret-token:super_secret' \
-    http://localhost:9966/instances/default/private/accounts \
+    http://localhost:9966/private/accounts \
     -d '{"payto_uri":"'"$FORTYTHREE"'"}' \
     -w "%{http_code}" -s -o /dev/null)
 
@@ -81,7 +91,7 @@ INFINITE_PRODUCT_TEMPLATE='{"product_id":"2","description":"product with id 2 an
 MANAGED_PRODUCT_TEMPLATE='{"product_id":"3","description":"product with id 3 and price :10","price":"TESTKUDOS:150","total_stock":2,"unit":"","image":"'"$RANDOM_IMG"'","taxes":[]}'
 
 echo -n "Creating products..."
-STATUS=$(curl 'http://localhost:9966/instances/default/private/products' \
+STATUS=$(curl 'http://localhost:9966/private/products' \
     -d "$INFINITE_PRODUCT_TEMPLATE" \
     -w "%{http_code}" -s -o /dev/null)
 
@@ -90,7 +100,7 @@ then
     exit_fail "Expected 204, product created. got: $STATUS"
 fi
 
-STATUS=$(curl 'http://localhost:9966/instances/default/private/products' \
+STATUS=$(curl 'http://localhost:9966/private/products' \
     -d "$MANAGED_PRODUCT_TEMPLATE" \
     -w "%{http_code}" -s -o /dev/null)
 
@@ -104,7 +114,7 @@ echo "OK"
 PRODUCT_DATA=$(echo "$INFINITE_PRODUCT_TEMPLATE" | jq 'del(.product_id) | . + {description: "other description"}')
 
 echo -n "Updating infinite stock product..."
-STATUS=$(curl 'http://localhost:9966/instances/default/private/products/2' -X PATCH \
+STATUS=$(curl 'http://localhost:9966/private/products/2' -X PATCH \
     -d "$PRODUCT_DATA" \
     -w "%{http_code}" -s -o "$LAST_RESPONSE")
 
@@ -114,7 +124,7 @@ then
     exit_fail "Expected 204, updating product. got: $STATUS"
 fi
 
-STATUS=$(curl 'http://localhost:9966/instances/default/private/products/2' \
+STATUS=$(curl 'http://localhost:9966/private/products/2' \
     -w "%{http_code}" -s -o "$LAST_RESPONSE")
 
 DESCRIPTION=$(jq -r .description < "$LAST_RESPONSE")
@@ -130,7 +140,7 @@ MANAGED_PRODUCT_ID=$(echo "$MANAGED_PRODUCT_TEMPLATE" | jq -r '.product_id')
 
 echo -n "Locking inventory ..."
 
-STATUS=$(curl "http://localhost:9966/instances/default/private/products/${MANAGED_PRODUCT_ID}/lock" \
+STATUS=$(curl "http://localhost:9966/private/products/${MANAGED_PRODUCT_ID}/lock" \
     -d '{"lock_uuid":"luck","duration":{"d_us": 100000000},"quantity":10}' \
     -w "%{http_code}" -s -o "$LAST_RESPONSE")
 
@@ -142,7 +152,7 @@ fi
 
 echo -n "."
 
-STATUS=$(curl "http://localhost:9966/instances/default/private/products/${MANAGED_PRODUCT_ID}/lock" \
+STATUS=$(curl "http://localhost:9966/private/products/${MANAGED_PRODUCT_ID}/lock" \
     -d '{"lock_uuid":"luck","duration":{"d_us": 100000000},"quantity":1}' \
     -w "%{http_code}" -s -o "$LAST_RESPONSE")
 
@@ -154,7 +164,7 @@ fi
 echo " OK"
 
 echo -n "Creating order to be paid..."
-STATUS=$(curl 'http://localhost:9966/instances/default/private/orders' \
+STATUS=$(curl 'http://localhost:9966/private/orders' \
     -d '{"order":{"amount":"TESTKUDOS:1","summary":"payme"},"inventory_products":[{"product_id":"'"${MANAGED_PRODUCT_ID}"'","quantity":1}]}' \
     -w "%{http_code}" -s -o "$LAST_RESPONSE")
 
@@ -167,7 +177,7 @@ fi
 ORDER_ID=$(jq -e -r .order_id < "$LAST_RESPONSE")
 #TOKEN=$(jq -e -r .token < "$LAST_RESPONSE")
 
-STATUS=$(curl "http://localhost:9966/instances/default/private/orders/${ORDER_ID}" \
+STATUS=$(curl "http://localhost:9966/private/orders/${ORDER_ID}" \
     -w "%{http_code}" -s -o "$LAST_RESPONSE")
 
 if [ "$STATUS" != "200" ]
@@ -179,7 +189,7 @@ PAY_URL=$(jq -e -r .taler_pay_uri < "$LAST_RESPONSE")
 
 echo -n "."
 
-STATUS=$(curl 'http://localhost:9966/instances/default/private/orders' \
+STATUS=$(curl 'http://localhost:9966/private/orders' \
     -d '{"order":{"amount":"TESTKUDOS:1","summary":"payme"},"inventory_products":[{"product_id":"'"${MANAGED_PRODUCT_ID}"'","quantity":1}]}' \
     -w "%{http_code}" -s -o "$LAST_RESPONSE")
 
@@ -192,7 +202,7 @@ fi
 echo -n "."
 
 # Using the 'luck' inventory lock, order creation should work.
-STATUS=$(curl 'http://localhost:9966/instances/default/private/orders' \
+STATUS=$(curl 'http://localhost:9966/private/orders' \
     -d '{"order":{"amount":"TESTKUDOS:1","summary":"payme"},"lock_uuids":["luck"],"inventory_products":[{"product_id":"'"$MANAGED_PRODUCT_ID"'","quantity":1}]}' \
     -w "%{http_code}" -s -o "$LAST_RESPONSE")
 
@@ -252,7 +262,7 @@ NOW2=$(date +%s)
 echo " OK (took $(( NOW2 -  NOW)) secs )"
 
 
-STATUS=$(curl "http://localhost:9966/instances/default/private/orders/${ORDER_ID}" \
+STATUS=$(curl "http://localhost:9966/private/orders/${ORDER_ID}" \
     -w "%{http_code}" -s -o "$LAST_RESPONSE")
 
 if [ "$STATUS" != "200" ]
@@ -274,7 +284,7 @@ echo -n "Updating product..."
 
 PRODUCT_DATA=$(echo "$MANAGED_PRODUCT_TEMPLATE" | jq 'del(.product_id) | . + {"total_stock": (.total_stock + 2) }')
 
-STATUS=$(curl 'http://localhost:9966/instances/default/private/products/3' -X PATCH \
+STATUS=$(curl 'http://localhost:9966/private/products/3' -X PATCH \
     -d "$PRODUCT_DATA" \
     -w "%{http_code}" -s -o "$LAST_RESPONSE")
 
