@@ -192,18 +192,18 @@ kyc_get_cb (void *cls,
         GNUNET_free (dec);
         TALER_TESTING_FAIL (cs->is);
       }
-      eq += strlen ("/kyc-proof/");
-      eq = strstr (eq, "state=");
+      GNUNET_free (dec);
+
+      eq = strstr (url, "&state=");
       if (NULL == eq)
       {
         GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
                     "Received unexpected 'state'-less KYC URL `%s' (%s)\n",
                     url,
                     dec);
-        GNUNET_free (dec);
         TALER_TESTING_FAIL (cs->is);
       }
-      eq += strlen ("state=");
+      eq += strlen ("&state=");
       nq = strchr (eq, '&');
       if (NULL == nq)
         nq = eq + strlen (eq);
@@ -216,11 +216,9 @@ kyc_get_cb (void *cls,
         GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
                     "Received unexpected KYC URL `%s' (%s) - no h_payto in state\n",
                     url,
-                    dec);
-        GNUNET_free (dec);
+                    eq);
         TALER_TESTING_FAIL (cs->is);
       }
-      GNUNET_free (dec);
     }
     break;
   }
