@@ -64,6 +64,18 @@ struct OrdersState
    */
   const char *token_family_reference;
 
+  /**
+   * How many tokens of the token family created in
+   * @a token_family_reference are required as inputs.
+   */
+  unsigned int num_inputs;
+
+  /**
+   * How many tokens of the token family created in
+   * @a token_family_reference should be issued as outputs.
+   */
+  unsigned int num_outputs;
+
   /**
    * Contract terms obtained from the backend.
    */
@@ -349,7 +361,7 @@ order_cb (void *cls,
                   (int) por->hr.ec,
                   TALER_TESTING_interpreter_get_current_label (ps->is),
                   s);
-      GNUNET_free (s);
+      free (s);
       /**
        * Not failing, as test cases are _supposed_
        * to create non 200 OK situations.
@@ -657,9 +669,10 @@ orders_run3 (void *cls,
       TALER_TESTING_FAIL (is);
   }
   make_choices_json (slug, slug,
-                     1, 1,
-                     GNUNET_TIME_absolute_to_timestamp(now),
-                     GNUNET_TIME_absolute_to_timestamp(now),
+                     ps->num_inputs,
+                     ps->num_outputs,
+                     GNUNET_TIME_absolute_to_timestamp (now),
+                     GNUNET_TIME_absolute_to_timestamp (now),
                      &ps->choices);
 
   GNUNET_assert (0 ==
@@ -962,6 +975,8 @@ TALER_TESTING_cmd_merchant_post_orders_choices (
   const char *merchant_url,
   unsigned int http_status,
   const char *token_family_reference,
+  unsigned int num_inputs,
+  unsigned int num_outputs,
   const char *order_id,
   struct GNUNET_TIME_Timestamp refund_deadline,
   struct GNUNET_TIME_Timestamp pay_deadline,
@@ -978,6 +993,8 @@ TALER_TESTING_cmd_merchant_post_orders_choices (
                    &ps->order_terms);
   ps->http_status = http_status;
   ps->token_family_reference = token_family_reference;
+  ps->num_inputs = num_inputs;
+  ps->num_outputs = num_outputs;
   ps->expected_order_id = order_id;
   ps->merchant_url = merchant_url;
   ps->with_claim = true;
@@ -992,4 +1009,4 @@ TALER_TESTING_cmd_merchant_post_orders_choices (
 
     return cmd;
   }
-}
\ No newline at end of file
+}
